==> lucene9_9.10.0+dfsg.orig.tar.xz: lucene-9.10.0/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/TaxonomyFacetCounts.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.lucene.facet.taxonomy;

import java.io.IOException;
import java.util.List;
import org.apache.lucene.facet.FacetsCollector;
import org.apache.lucene.facet.FacetsCollector.MatchingDocs;
import org.apache.lucene.facet.FacetsConfig;
import org.apache.lucene.index.BinaryDocValues;
import org.apache.lucene.search.DocIdSetIterator;
import org.apache.lucene.util.IntsRef;

/**
 * Reads from any {@link OrdinalsReader}; use {@link FastTaxonomyFacetCounts} if you are using the
 * default encoding from {@link BinaryDocValues}.
 *
 * @deprecated Custom binary encodings for taxonomy ordinals are no longer supported starting with
 *     Lucene 9. Please switch to {@link FastTaxonomyFacetCounts} or implement your own {@link
 *     org.apache.lucene.facet.Facets} implementation if you have custom needs.
 */
@Deprecated
public class TaxonomyFacetCounts extends IntTaxonomyFacets {
  private final OrdinalsReader ordinalsReader;

  /**
   * Create {@code TaxonomyFacetCounts}, which also counts all facet labels. Use this for a
   * non-default {@link OrdinalsReader}; otherwise use {@link FastTaxonomyFacetCounts}.
   */
  public TaxonomyFacetCounts(
      OrdinalsReader ordinalsReader,
      TaxonomyReader taxoReader,
      FacetsConfig config,
      FacetsCollector fc)
      throws IOException {
    super(
        ordinalsReader.getIndexFieldName(),
        taxoReader,
        config,
        AssociationAggregationFunction.SUM,
        fc);
    this.ordinalsReader = ordinalsReader;
    count(fc.getMatchingDocs());
  }

  private final void count(List<MatchingDocs> matchingDocs) throws IOException {
    IntsRef scratch = new IntsRef();
    for (MatchingDocs hits : matchingDocs) {
      OrdinalsReader.OrdinalsSegmentReader ords = ordinalsReader.getReader(hits.context);
      DocIdSetIterator docs = hits.bits.iterator();

      int doc;
      while ((doc = docs.nextDoc()) != DocIdSetIterator.NO_MORE_DOCS) {
        ords.get(doc, scratch);
        for (int i = 0; i < scratch.length; i++) {
          increment(scratch.ints[scratch.offset + i]);
        }
      }
    }

    rollup();
  }
}

==> lucene9_9.12.3+dfsg.orig.tar.xz: lucene-9.12.3/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/TaxonomyFacetCounts.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.lucene.facet.taxonomy;

import java.io.IOException;
import java.util.List;
import org.apache.lucene.facet.FacetsCollector;
import org.apache.lucene.facet.FacetsCollector.MatchingDocs;
import org.apache.lucene.facet.FacetsConfig;
import org.apache.lucene.index.BinaryDocValues;
import org.apache.lucene.search.DocIdSetIterator;
import org.apache.lucene.util.IntsRef;

/**
 * Reads from any {@link OrdinalsReader}; use {@link FastTaxonomyFacetCounts} if you are using the
 * default encoding from {@link BinaryDocValues}.
 *
 * @deprecated Custom binary encodings for taxonomy ordinals are no longer supported starting with
 *     Lucene 9. Please switch to {@link FastTaxonomyFacetCounts} or implement your own {@link
 *     org.apache.lucene.facet.Facets} implementation if you have custom needs.
 */
@Deprecated
public class TaxonomyFacetCounts extends IntTaxonomyFacets {
  private final OrdinalsReader ordinalsReader;

  /**
   * Create {@code TaxonomyFacetCounts}, which also counts all facet labels. Use this for a
   * non-default {@link OrdinalsReader}; otherwise use {@link FastTaxonomyFacetCounts}.
   */
  public TaxonomyFacetCounts(
      OrdinalsReader ordinalsReader,
      TaxonomyReader taxoReader,
      FacetsConfig config,
      FacetsCollector fc)
      throws IOException {
    super(
        ordinalsReader.getIndexFieldName(),
        taxoReader,
        config,
        AssociationAggregationFunction.SUM,
        fc);
    this.ordinalsReader = ordinalsReader;
    count(fc.getMatchingDocs());
  }

  private final void count(List<MatchingDocs> matchingDocs) throws IOException {
    IntsRef scratch = new IntsRef();
    for (MatchingDocs hits : matchingDocs) {
      if (hits.totalHits == 0) {
        continue;
      }
      initializeValueCounters();

      OrdinalsReader.OrdinalsSegmentReader ords = ordinalsReader.getReader(hits.context);
      DocIdSetIterator docs = hits.bits.iterator();

      int doc;
      while ((doc = docs.nextDoc()) != DocIdSetIterator.NO_MORE_DOCS) {
        ords.get(doc, scratch);
        for (int i = 0; i < scratch.length; i++) {
          int ord = scratch.ints[scratch.offset + i];
          int count = getCount(ord) + 1;
          setCount(ord, count);
          setValue(ord, count);
        }
      }
    }

    rollup();
  }
}
